@@ -1,3 +1,4 @@
+import logging
 from typing import List, Dict, Tuple
 
 from .base_ssdb import BaseSsdb
@@ -90,11 +91,17 @@ class SsdbSortedSet(BaseSsdbSortedSet):
         if len(ranks) > 0:
             start_rank, end_rank = max(0, min(ranks)), max(ranks)
             response = self.execute_command('zrange', name, start_rank, end_rank + 1)
-            rank_to_id_map = SsdbResponseUtils.to_rank_to_id_map(response, start_rank)
+            rank_to_id_map = SsdbResponseUtils.to_rank_to_id_map(response, ranks, start_rank)
+
             for rank in ranks:
                 if rank in rank_to_id_map.keys():
                     actual_result_map[rank] = rank_to_id_map[rank]
 
+            logging.info('multi_get_item_by_ranking')
+            logging.info(f"Range: [{start_rank}, {end_rank + 1})")
+            logging.info(f"Response Size: {len(response[::2])}")
+            logging.info(f"Final Size: {len(actual_result_map.keys())}")
+
         return actual_result_map
 
     def zdel(self, name: str, key: str):
